# Welcome to PyFlowery

/// admonition | This project is in active development
    type: warning
These docs are not complete yet, and there is a lot still to do.
///

**PyFlowery** is a Python API Wrapper for the [Flowery](https://flowery.pw/about) API.

Check out the [usage](getting-started/usage.md) section for further information.  
Installation instructions can be found [here](getting-started/installation.md).
